benji — ceph rbd backup - fast open source block based backup software

# Hi, I'm benji, a reliable open source
block based backup software

I deduplicate data, store to s3 or filesytems and
I have special features for ceph/rbd volumes.
I'm blazingly fast.

Download .deb or src (zip)

- Discover

## For your whole infrastructure.

Backup any block based device, like LVM volumes, whole disks or ceph/rbd volumes. In contrast to other backup solutions, benji always backs up all data on the disk, including the bootloader, kernel and partition data.

As benji deduplicates all data before writing it, it's possible to backup a whole rack with nothing more than a 1 gbit link.

## „This is amazing software - looks like the backup solution I’ve been searching for to use with Ceph.“

Brian Chamberlain, I.P. Telecom Limited

## Key Features

Using all your disks in parallel
  benji reads from multiple disks and writes to multiple disks simultaniously. You'll get the most out of your disk arrays, NAS, SAN, Ceph or RAID.
Small and fast backups
  benji deduplicates while reading from the block device and only writes blocks once if they are the same. With the help of ceph’s rbd diff, benji will only read the changed blocks since the last backup.
Fast restores
  With supporting block storage (like ceph/rbd), fast sparse restores are possible.
Partial restores / directly mount your backups
  With its own NBD server, benji backups can be directly mounted on any linux system.
High data consistency
  Every backed up piece of data has a checksum stored with it and benji can scrub the backup data and check for correctness of the backups.
It will prevent you from doing stupid things
  benji will not execute commands that will destroy data, unless you `--force` it to.
Parallel: backups while scrubbing while restoring
  Parallel execution of multiple benji processes is fully supported.
Easy installation
  dpkg -i backy*.deb
Free and Open Source Software
  Anyone can review the source code and audit security and functionality. benji is licensed under the LGPLv3 license.

## „ And what a smooth piece of software, it really deserves to be the top spot on any google search on "ceph backup". “

sep76, reddit

## You can use benji today.

Just read the docs, download the code or a .deb release and get support.

### Documentation

Learn all about backup, scrub and restore with benji.

- Documentation

### Support

Get support and help other users on IRC freenode.net.

- Chat

### Code

Download the code, .deb releases and participate.

- GitHub

## Need professional support?

We do benji consulting.

- Contact us ✉

- GitHub
- Email

- © D9T GmbH
- Imprint
- Privacy
- Design: HTML5 UP